==> message-bus-common-1.0.6.8-20210629.074702-50-sources.jar: com/xforceplus/janus/message/common/config/ApplicationProperties.java <==
package com.xforceplus.janus.message.common.config;

import lombok.Data;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;

import java.util.List;

/**
 * Properties specific to Application.
 *
 * <p>
 * Properties are configured in the application.yml file.
 * </p>
 *
 * @author liuyao@xforceplus.com
 * @version 1.0
 * @date 2020/6/2 10:33
 */
@Slf4j
@Component
@ConfigurationProperties(prefix = "application")
@Validated
@Getter
public class ApplicationProperties {
    private final Swagger             swagger             = new Swagger();
    private final AopLogging          aopLogging          = new AopLogging();
    private final AopAuth             aopAuth             = new AopAuth();
    private final RateLimit           rateLimit           = new RateLimit();
    private final RefreshCacheHistory refreshCacheHistory = new RefreshCacheHistory();
    private final HttpClient          httpClient          = new HttpClient();

    @Data
    public static class Swagger {
        private boolean enabled;
        private Api     api     = new Api();
        private OpenApi openApi = new OpenApi();
        private String  version;
        private String  contactName;
        private String  contactEmail;
        private String  host;

        @Data
        public static class Api {
            private String title;
            private String description;
        }

        @Data
        public static class OpenApi {
            private String title;
            private String description;
        }
    }

    @Data
    public static class AopLogging {
        private boolean      enabled;
        private boolean      methodWhitelistMode;
        private List<String> methodWhitelist;
    }

    @Data
    public static class AopAuth {
        private boolean enabled;
    }

    @Data
    public static class RateLimit {
        private boolean enabled;
        private String  name;
        private long    permitsPerSecond;
    }

    @Data
    public static class RefreshCacheHistory {
        private boolean enabled;
        private int     maxRecords;
    }

    @Data
    public static class HttpClient {
        private int     readTimeout;
        private int     retryCount;
        private boolean enableLogRequest;
        private boolean enableLogResponseStatus;
        private boolean enableLogResponseBody;
    }
}

==> message-bus-common-1.0.6.8-20210727.013213-76-sources.jar: com/xforceplus/janus/message/common/config/ApplicationProperties.java <==
package com.xforceplus.janus.message.common.config;

import lombok.Data;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;

import java.util.List;

/**
 * Properties specific to Application.
 *
 * <p>
 * Properties are configured in the application.yml file.
 * </p>
 *
 * @author liuyao@xforceplus.com
 * @version 1.0
 * @date 2020/6/2 10:33
 */
@Slf4j
@Component
@ConfigurationProperties(prefix = "application")
@Validated
@Getter
public class ApplicationProperties {
    private final Swagger             swagger             = new Swagger();
    private final AopLogging          aopLogging          = new AopLogging();
    private final AopAuth             aopAuth             = new AopAuth();
    private final RateLimit           rateLimit           = new RateLimit();
    private final RefreshCacheHistory refreshCacheHistory = new RefreshCacheHistory();
    private final HttpClient          httpClient          = new HttpClient();
    private final AppTenant           appTenant           = new AppTenant();

    @Data
    public static class Swagger {
        private boolean enabled;
        private Api     api     = new Api();
        private OpenApi openApi = new OpenApi();
        private String  version;
        private String  contactName;
        private String  contactEmail;
        private String  host;

        @Data
        public static class Api {
            private String title;
            private String description;
        }

        @Data
        public static class OpenApi {
            private String title;
            private String description;
        }
    }

    @Data
    public static class AopLogging {
        private boolean      enabled;
        private boolean      methodWhitelistMode;
        private List<String> methodWhitelist;
    }

    @Data
    public static class AopAuth {
        private boolean enabled;
    }

    @Data
    public static class RateLimit {
        private boolean enabled;
        private String  name;
        private long    permitsPerSecond;
    }

    @Data
    public static class RefreshCacheHistory {
        private boolean enabled;
        private int     maxRecords;
    }

    @Data
    public static class HttpClient {
        private int     readTimeout;
        private int     retryCount;
        private boolean enableLogRequest;
        private boolean enableLogResponseStatus;
        private boolean enableLogResponseBody;
    }

    @Data
    public static class AppTenant {
        /**
         * 邮件模版跟该appId进行关联
         */
        private long emailAppId;
        private long emailTenantId = 0L;
        /**
         * 该appId和tenantId组合代表使用阿里云短信账号
         */
        private long smsAppId;
        /**
         * 该appId和tenantId组合代表使用阿里云短信账号
         */
        private long smsTenantId   = 0L;
    }
}
